@@ -60,6 +60,7 @@ public class JmsConnectionFactory extends JNDIStorable implements ConnectionFact
     private boolean alwaysSyncSend;
     private boolean sendAcksAsync;
     private boolean localMessagePriority;
+    private boolean localMessageExpiry = true;
     private String queuePrefix = null;
     private String topicPrefix = null;
     private boolean validatePropertyNames = true;
@@ -346,7 +347,7 @@ public class JmsConnectionFactory extends JNDIStorable implements ConnectionFact
     }
 
     /**
-     * @return the username
+     * @return the user name used for connection authentication.
      */
     public String getUsername() {
         return this.username;
@@ -354,14 +355,14 @@ public class JmsConnectionFactory extends JNDIStorable implements ConnectionFact
 
     /**
      * @param username
-     *        the username to set
+     *        the user name to set
      */
     public void setUsername(String username) {
         this.username = username;
     }
 
     /**
-     * @return the password
+     * @return the password set for connection authentication.
      */
     public String getPassword() {
         return this.password;
@@ -647,4 +648,23 @@ public class JmsConnectionFactory extends JNDIStorable implements ConnectionFact
     public void setSendAcksAsync(boolean sendAcksAsync) {
         this.sendAcksAsync = sendAcksAsync;
     }
+
+    /**
+     * @return true if MessageConsumer instance will check for expired messages locally before dispatch.
+     */
+    public boolean isLocalMessageExpiry() {
+        return localMessageExpiry;
+    }
+
+    /**
+     * Controls whether message expiration checking is done locally (in addition to any broker
+     * side checks) in each MessageConsumer prior to dispatching a message.  Disabling this check
+     * can lead to consumption of expired messages.
+     *
+     * @param localMessageExpiry
+     *        controls whether expiration checking is done prior to dispatch.
+     */
+    public void setLocalMessageExpiry(boolean localMessageExpiry) {
+        this.localMessageExpiry = localMessageExpiry;
+    }
 }
