@@ -40,12 +40,16 @@ import org.apache.qpid.jms.provider.ProviderFuture;
 import org.apache.qpid.jms.util.FifoMessageQueue;
 import org.apache.qpid.jms.util.MessageQueue;
 import org.apache.qpid.jms.util.PriorityMessageQueue;
+import org.slf4j.Logger;
+import org.slf4j.LoggerFactory;
 
 /**
  * implementation of a JMS Message Consumer
  */
 public class JmsMessageConsumer implements MessageConsumer, JmsMessageAvailableConsumer, JmsMessageDispatcher {
 
+    private static final Logger LOG = LoggerFactory.getLogger(JmsMessageConsumer.class);
+
     protected final JmsSession session;
     protected final JmsConnection connection;
     protected JmsConsumerInfo consumerInfo;
@@ -115,6 +119,7 @@ public class JmsMessageConsumer implements MessageConsumer, JmsMessageAvailableC
         consumerInfo.setBrowser(isBrowser());
         consumerInfo.setPrefetchSize(getConfiguredPrefetch(destination, policy));
         consumerInfo.setRedeliveryPolicy(redeliveryPolicy);
+        consumerInfo.setLocalMessageExpiry(connection.isLocalMessageExpiry());
 
         session.getConnection().createResource(consumerInfo);
     }
@@ -215,18 +220,13 @@ public class JmsMessageConsumer implements MessageConsumer, JmsMessageAvailableC
     public Message receive(long timeout) throws JMSException {
         checkClosed();
         checkMessageListener();
-        sendPullCommand(timeout);
 
-        long wait = timeout;
+        // Configure for infinite wait when timeout is zero (JMS Spec)
         if (timeout == 0) {
-            wait = -1;
+            timeout = -1;
         }
 
-        try {
-            return copy(ackFromReceive(this.messageQueue.dequeue(wait)));
-        } catch (InterruptedException e) {
-            throw JmsExceptionSupport.create(e);
-        }
+        return copy(ackFromReceive(dequeue(timeout)));
     }
 
     /**
@@ -238,9 +238,100 @@ public class JmsMessageConsumer implements MessageConsumer, JmsMessageAvailableC
     public Message receiveNoWait() throws JMSException {
         checkClosed();
         checkMessageListener();
-        sendPullCommand(-1);
+        return copy(ackFromReceive(dequeue(0)));
+    }
 
-        return copy(ackFromReceive(this.messageQueue.dequeueNoWait()));
+    /**
+     * Used to get an enqueued message from the unconsumedMessages list. The
+     * amount of time this method blocks is based on the timeout value.
+     *
+     *   timeout < 0 then it blocks until a message is received.
+     *   timeout = 0 then it returns a message or null if none available
+     *   timeout > 0 then it blocks up to timeout amount of time.
+     *
+     * This method may consume messages that are expired or exceed a configured
+     * delivery count value but will continue to wait for the configured timeout.
+     *
+     * @throws JMSException
+     * @return null if we timeout or if the consumer is closed.
+     */
+    private JmsInboundMessageDispatch dequeue(long timeout) throws JMSException {
+
+        try {
+            long deadline = 0;
+            if (timeout > 0) {
+                deadline = System.currentTimeMillis() + timeout;
+            }
+
+            sendPullCommand(timeout);
+
+            while (true) {
+                JmsInboundMessageDispatch envelope = null;
+                if (isPullConsumer()) {
+                    envelope = messageQueue.dequeue(-1);
+                } else {
+                    envelope = messageQueue.dequeue(timeout);
+                }
+
+                if (envelope == null) {
+
+                    if (failureCause != null && !messageQueue.isClosed() && timeout == 0) {
+                        LOG.debug("{} receive failed: {}", getConsumerId(), failureCause.getMessage());
+                        throw JmsExceptionSupport.create(failureCause);
+                    }
+
+                    if (timeout == 0 || messageQueue.isClosed()) {
+                        return null;
+                    } else if (timeout > 0) {
+                        timeout = Math.max(deadline - System.currentTimeMillis(), 0);
+                    }
+
+                    sendPullCommand(timeout);
+                } else if (envelope.getMessage() == null) {
+                    LOG.trace("{} no message was available for this consumer: {}", getConsumerId());
+                    return null;
+                } else if (consumeExpiredMessage(envelope)) {
+                    LOG.trace("{} filtered expired message: {}", getConsumerId(), envelope);
+                    doAckExpired(envelope);
+                    if (timeout > 0) {
+                        timeout = Math.max(deadline - System.currentTimeMillis(), 0);
+                    }
+                    sendPullCommand(timeout);
+                } else if (redeliveryExceeded(envelope)) {
+                    LOG.debug("{} filtered message with excessive redelivery count: {}", getConsumerId(), envelope);
+                    doAckUndeliverable(envelope);
+                    if (timeout > 0) {
+                        timeout = Math.max(deadline - System.currentTimeMillis(), 0);
+                    }
+                    sendPullCommand(timeout);
+                } else {
+                    if (LOG.isTraceEnabled()) {
+                        LOG.trace(getConsumerId() + " received message: " + envelope);
+                    }
+                    return envelope;
+                }
+            }
+        } catch (InterruptedException e) {
+            Thread.currentThread().interrupt();
+            throw JmsExceptionSupport.create(e);
+        }
+    }
+
+    private boolean consumeExpiredMessage(JmsInboundMessageDispatch dispatch) {
+        if (!isBrowser() && consumerInfo.isLocalMessageExpiry() && dispatch.getMessage().isExpired()) {
+            return true;
+        }
+
+        return false;
+    }
+
+    protected boolean redeliveryExceeded(JmsInboundMessageDispatch envelope) {
+        LOG.trace("checking envelope with {} redeliveries", envelope.getRedeliveryCount());
+
+        JmsRedeliveryPolicy redeliveryPolicy = consumerInfo.getRedeliveryPolicy();
+        return redeliveryPolicy != null &&
+               redeliveryPolicy.getMaxRedeliveries() != JmsRedeliveryPolicy.DEFAULT_MAX_REDELIVERIES &&
+               redeliveryPolicy.getMaxRedeliveries() < envelope.getRedeliveryCount();
     }
 
     protected void checkClosed() throws IllegalStateException {
@@ -303,6 +394,24 @@ public class JmsMessageConsumer implements MessageConsumer, JmsMessageAvailableC
         return envelope;
     }
 
+    private void doAckExpired(final JmsInboundMessageDispatch envelope) throws JMSException {
+        try {
+            session.acknowledge(envelope, ACK_TYPE.EXPIRED);
+        } catch (JMSException ex) {
+            session.onException(ex);
+            throw ex;
+        }
+    }
+
+    private void doAckUndeliverable(final JmsInboundMessageDispatch envelope) throws JMSException {
+        try {
+            session.acknowledge(envelope, ACK_TYPE.POISONED);
+        } catch (JMSException ex) {
+            session.onException(ex);
+            throw ex;
+        }
+    }
+
     private void doAckReleased(final JmsInboundMessageDispatch envelope) throws JMSException {
         try {
             session.acknowledge(envelope, ACK_TYPE.RELEASED);
@@ -500,6 +609,10 @@ public class JmsMessageConsumer implements MessageConsumer, JmsMessageAvailableC
         return false;
     }
 
+    public boolean isPullConsumer() {
+        return getPrefetchSize() == 0;
+    }
+
     @Override
     public void setAvailableListener(JmsMessageAvailableListener availableListener) {
         this.availableListener = availableListener;
@@ -524,28 +637,48 @@ public class JmsMessageConsumer implements MessageConsumer, JmsMessageAvailableC
         ProviderFuture request = new ProviderFuture();
         provider.start(consumerInfo, request);
         request.sync();
+
+        // For a pull consumer we want to stop the Queue waking an blocked receives and
+        // preventing a new one from blocking until it has reissued a new pull.
+        if (isPullConsumer()) {
+            lock.lock();
+            try {
+                messageQueue.stop();
+            } finally {
+                lock.unlock();
+            }
+        }
     }
 
     protected void onConnectionRestored() {
     }
 
     /**
-     * Triggers a pull request from the connected Provider.  An attempt is made to set
-     * a timeout on the pull request however some providers will not honor this value
-     * and the pull will remain active until a message is dispatched.
+     * Triggers a pull request from the connected Provider with the given timeout value.
      * <p>
      * The timeout value can be one of:
      * <br>
-     * {@literal < 0} to indicate that the request should expire immediately if no message.<br>
-     * {@literal = 0} to indicate that the request should never time out.<br>
-     * {@literal > 1} to indicate that the request should expire after the given time in milliseconds.
+     * {@literal < 0} to indicate that the request should never time out.<br>
+     * {@literal = 0} to indicate that the request should expire immediately if no message.<br>
+     * {@literal > 0} to indicate that the request should expire after the given time in milliseconds.
      *
      * @param timeout
      *        The amount of time the pull request should remain valid.
      */
     protected void sendPullCommand(long timeout) throws JMSException {
-        if (messageQueue.isEmpty() && (getPrefetchSize() == 0 || isBrowser())) {
+        if (!messageQueue.isClosed() && messageQueue.isEmpty() && (getPrefetchSize() == 0 || isBrowser())) {
             connection.pull(getConsumerId(), timeout);
+
+            // Once a new pull has gone out check to see if the queue was stopped due to failover
+            // and restart it so that the receive calls can once again start blocking on dequeue.
+            lock.lock();
+            try {
+                if (started) {
+                    messageQueue.start();
+                }
+            } finally {
+                lock.unlock();
+            }
         }
     }
 
@@ -575,19 +708,28 @@ public class JmsMessageConsumer implements MessageConsumer, JmsMessageAvailableC
             while (session.isStarted() && (envelope = messageQueue.dequeueNoWait()) != null) {
                 try {
                     JmsMessage copy = null;
-                    boolean autoAckOrDupsOk = acknowledgementMode == Session.AUTO_ACKNOWLEDGE ||
-                                              acknowledgementMode == Session.DUPS_OK_ACKNOWLEDGE;
-                    if (autoAckOrDupsOk) {
-                        copy = copy(doAckDelivered(envelope));
+
+                    if (consumeExpiredMessage(envelope)) {
+                        LOG.trace("{} filtered expired message: {}", getConsumerId(), envelope);
+                        doAckExpired(envelope);
+                    } else if (redeliveryExceeded(envelope)) {
+                        LOG.trace("{} filtered message with excessive redelivery count: {}", getConsumerId(), envelope);
+                        doAckUndeliverable(envelope);
                     } else {
-                        copy = copy(ackFromReceive(envelope));
-                    }
-                    session.clearSessionRecovered();
+                        boolean autoAckOrDupsOk = acknowledgementMode == Session.AUTO_ACKNOWLEDGE ||
+                                                  acknowledgementMode == Session.DUPS_OK_ACKNOWLEDGE;
+                        if (autoAckOrDupsOk) {
+                            copy = copy(doAckDelivered(envelope));
+                        } else {
+                            copy = copy(ackFromReceive(envelope));
+                        }
+                        session.clearSessionRecovered();
 
-                    messageListener.onMessage(copy);
+                        messageListener.onMessage(copy);
 
-                    if (autoAckOrDupsOk && !session.isSessionRecovered()) {
-                        doAckConsumed(envelope);
+                        if (autoAckOrDupsOk && !session.isSessionRecovered()) {
+                            doAckConsumed(envelope);
+                        }
                     }
                 } catch (Exception e) {
                     // TODO - We need to handle exception of on message with some other
