@@ -31,6 +31,7 @@ public final class JmsConsumerInfo implements JmsResource, Comparable<JmsConsume
     protected String subscriptionName;
     protected boolean noLocal;
     protected int acknowledgementMode;
+    protected boolean localMessageExpiry;
 
     protected JmsRedeliveryPolicy redeliveryPolicy;
 
@@ -153,6 +154,14 @@ public final class JmsConsumerInfo implements JmsResource, Comparable<JmsConsume
         this.acknowledgementMode = acknowledgementMode;
     }
 
+    public boolean isLocalMessageExpiry() {
+        return localMessageExpiry;
+    }
+
+    public void setLocalMessageExpiry(boolean localMessageExpiry) {
+        this.localMessageExpiry = localMessageExpiry;
+    }
+
     public JmsRedeliveryPolicy getRedeliveryPolicy() {
         return redeliveryPolicy;
     }
