@@ -18,7 +18,6 @@ package org.apache.qpid.jms.provider;
 
 import java.io.IOException;
 import java.net.URI;
-import java.security.Principal;
 
 import javax.jms.JMSException;
 
@@ -29,7 +28,6 @@ import org.apache.qpid.jms.meta.JmsConsumerId;
 import org.apache.qpid.jms.meta.JmsResource;
 import org.apache.qpid.jms.meta.JmsSessionId;
 import org.apache.qpid.jms.provider.ProviderConstants.ACK_TYPE;
-import org.apache.qpid.jms.transports.SSLTransport;
 
 /**
  * Defines the interface that an Implementation of a Specific wire level protocol
@@ -130,7 +128,7 @@ public interface Provider {
      * need to be started again via a call to <code>start()</code>
      *
      * For some JMS Resources it is necessary or advantageous to have a stopped state that
-     * cam be triggered to stop the resource generating new events or messages.
+     * can be triggered to stop the resource generating new events or messages.
      *
      * An example of this would be a JMS Session which should not receive any incoming messages
      * for any consumers until the JMS layer is in a state to handle them.  One such time would be
@@ -283,7 +281,13 @@ public interface Provider {
      * Request a remote peer send a Message to this client.  A message pull request is
      * usually only needed in the case where the client sets a zero prefetch limit on the
      * consumer.  If the consumer has a set prefetch that's greater than zero this method
-     * should just return without performing and action.
+     * should just return without performing any action.
+     *
+     *   {@literal timeout < 0} then it should remain open until a message is received.
+     *   {@literal timeout = 0} then it returns a message or null if none available
+     *   {@literal timeout > 0} then it should remain open for timeout amount of time.
+     *
+     * The timeout value when positive is given in milliseconds.
      *
      * @param timeout
      *        the amount of time to tell the remote peer to keep this pull request valid.
@@ -317,12 +321,4 @@ public interface Provider {
      * @return the currently set ProviderListener instance.
      */
     ProviderListener getProviderListener();
-
-    /**
-     * Get the local Principal associated with the {@link SSLTransport}
-     * if the Provider is using one.
-     *
-     * @return the {@link Principal}, or null if there isn't one
-     */
-    Principal getLocalPrincipal();
 }
