@@ -141,11 +141,6 @@ public class AmqpJmsMessageFacade implements JmsMessageFacade {
         message.setContentType(value);
     }
 
-    @Override
-    public boolean isEmpty() {
-        return true;
-    }
-
     @Override
     public boolean propertyExists(String key) throws JMSException {
         return AmqpJmsMessagePropertyIntercepter.propertyExists(this, key);
