@@ -60,8 +60,8 @@ public class FailoverRedirectTest extends QpidJmsTestCase {
             final String redirectURI = createPeerURI(redirectedPeer);
             LOG.info("Backup peer is at: {}", redirectURI);
 
-            redirectedPeer.expectAnonymousConnect(true);
-            redirectedPeer.expectBegin(true);
+            redirectedPeer.expectSaslAnonymousConnect();
+            redirectedPeer.expectBegin();
 
             Map<Symbol, Object> redirectInfo = new HashMap<Symbol, Object>();
             redirectInfo.put(OPEN_HOSTNAME, "localhost");
@@ -103,16 +103,16 @@ public class FailoverRedirectTest extends QpidJmsTestCase {
             final String redirectURI = createPeerURI(redirectedPeer);
             LOG.info("Primary is at {}: Backup peer is at: {}", rejectingURI, redirectURI);
 
-            redirectedPeer.expectAnonymousConnect(true);
-            redirectedPeer.expectBegin(true);
+            redirectedPeer.expectSaslAnonymousConnect();
+            redirectedPeer.expectBegin();
 
             Map<Symbol, Object> redirectInfo = new HashMap<Symbol, Object>();
             redirectInfo.put(OPEN_HOSTNAME, "localhost");
             redirectInfo.put(NETWORK_HOST, "localhost");
             redirectInfo.put(PORT, redirectedPeer.getServerPort());
 
-            rejectingPeer.expectAnonymousConnect(true);
-            rejectingPeer.expectBegin(true);
+            rejectingPeer.expectSaslAnonymousConnect();
+            rejectingPeer.expectBegin();
             rejectingPeer.remotelyCloseConnection(true, ConnectionError.REDIRECT, "Server is full, go away", redirectInfo);
 
             final JmsConnection connection = establishAnonymousConnecton(rejectingPeer);
