@@ -97,6 +97,8 @@ public class TestAmqpPeer implements AutoCloseable
 {
     private static final Logger LOGGER = LoggerFactory.getLogger(TestAmqpPeer.class.getName());
 
+    public static final String MESSAGE_NUMBER = "MessageNumber";
+
     private static final Symbol ANONYMOUS = Symbol.valueOf("ANONYMOUS");
     private static final Symbol EXTERNAL = Symbol.valueOf("EXTERNAL");
     private static final Symbol PLAIN = Symbol.valueOf("PLAIN");
@@ -133,7 +135,7 @@ public class TestAmqpPeer implements AutoCloseable
     public TestAmqpPeer(SSLContext context, boolean needClientCert) throws IOException
     {
         _driverRunnable = new TestAmqpPeerRunner(this, context, needClientCert);
-        _driverThread = new Thread(_driverRunnable, "MockAmqpPeerThread");
+        _driverThread = new Thread(_driverRunnable, "MockAmqpPeer-" + _driverRunnable.getServerPort());
         _driverThread.start();
     }
 
@@ -300,16 +302,20 @@ public class TestAmqpPeer implements AutoCloseable
     }
 
     public void waitForAllHandlersToComplete(int timeoutMillis) throws InterruptedException
+    {
+        boolean countedDownOk =  waitForAllHandlersToCompleteNoAssert(timeoutMillis);
+
+        Assert.assertTrue("All handlers should have completed within the " + timeoutMillis + "ms timeout", countedDownOk);
+    }
+
+    public boolean waitForAllHandlersToCompleteNoAssert(int timeoutMillis) throws InterruptedException
     {
         synchronized(_handlersLock)
         {
             _handlersCompletedLatch = new CountDownLatch(_handlers.size());
         }
 
-        boolean countedDownOk = _handlersCompletedLatch.await(timeoutMillis, TimeUnit.MILLISECONDS);
-
-        Assert.assertTrue(
-                "All handlers should have completed within the " + timeoutMillis + "ms timeout", countedDownOk);
+        return _handlersCompletedLatch.await(timeoutMillis, TimeUnit.MILLISECONDS);
     }
 
     void sendHeader(byte[] header)
@@ -1098,7 +1104,7 @@ public class TestAmqpPeer implements AutoCloseable
 
     public void expectLinkFlow(boolean drain, boolean sendDrainFlowResponse, Matcher<UnsignedInteger> creditMatcher)
     {
-        expectLinkFlowRespondWithTransfer(null, null, null, null, null, 0, drain, sendDrainFlowResponse, creditMatcher, null);
+        expectLinkFlowRespondWithTransfer(null, null, null, null, null, 0, drain, sendDrainFlowResponse, creditMatcher, null, false);
     }
 
     public void expectLinkFlowRespondWithTransfer(final HeaderDescribedType headerDescribedType,
@@ -1120,19 +1126,20 @@ public class TestAmqpPeer implements AutoCloseable
     {
         expectLinkFlowRespondWithTransfer(headerDescribedType, messageAnnotationsDescribedType, propertiesDescribedType,
                                           appPropertiesDescribedType, content, count, false, false,
-                                          Matchers.greaterThanOrEqualTo(UnsignedInteger.valueOf(count)), 1);
+                                          Matchers.greaterThanOrEqualTo(UnsignedInteger.valueOf(count)), 1, false);
     }
 
     public void expectLinkFlowRespondWithTransfer(final HeaderDescribedType headerDescribedType,
             final MessageAnnotationsDescribedType messageAnnotationsDescribedType,
             final PropertiesDescribedType propertiesDescribedType,
-            final ApplicationPropertiesDescribedType appPropertiesDescribedType,
+            ApplicationPropertiesDescribedType appPropertiesDescribedType,
             final DescribedType content,
             final int count,
             final boolean drain,
             final boolean sendDrainFlowResponse,
             Matcher<UnsignedInteger> creditMatcher,
-            final Integer nextIncomingId)
+            final Integer nextIncomingId,
+            boolean addMessageNumberProperty)
     {
         if (nextIncomingId == null && count > 0)
         {
@@ -1167,6 +1174,10 @@ public class TestAmqpPeer implements AutoCloseable
         CompositeAmqpPeerRunnable composite = new CompositeAmqpPeerRunnable();
         boolean addComposite = false;
 
+        if (appPropertiesDescribedType == null && addMessageNumberProperty) {
+            appPropertiesDescribedType = new ApplicationPropertiesDescribedType();
+        }
+
         for(int i = 0; i < count; i++)
         {
             final int nextId = nextIncomingId + i;
@@ -1174,6 +1185,10 @@ public class TestAmqpPeer implements AutoCloseable
             String tagString = "theDeliveryTag" + nextId;
             Binary dtag = new Binary(tagString.getBytes());
 
+            if(addMessageNumberProperty) {
+                appPropertiesDescribedType.setApplicationProperty(MESSAGE_NUMBER, i);
+            }
+
             final TransferFrame transferResponse = new TransferFrame()
             .setDeliveryId(UnsignedInteger.valueOf(nextId))
             .setDeliveryTag(dtag)
@@ -1284,12 +1299,18 @@ public class TestAmqpPeer implements AutoCloseable
 
     public void expectTransfer(Matcher<Binary> expectedPayloadMatcher)
     {
-        expectTransfer(expectedPayloadMatcher, nullValue(), false, new Accepted(), true);
+        expectTransfer(expectedPayloadMatcher, nullValue(), false, true, new Accepted(), true);
+    }
+
+    public void expectTransfer(Matcher<Binary> expectedPayloadMatcher, Matcher<?> stateMatcher, boolean settled,
+                               ListDescribedType responseState, boolean responseSettled)
+    {
+        expectTransfer(expectedPayloadMatcher, stateMatcher, settled, true, responseState, responseSettled);
     }
 
     //TODO: fix responseState to only admit applicable types.
     public void expectTransfer(Matcher<Binary> expectedPayloadMatcher, Matcher<?> stateMatcher, boolean settled,
-                               ListDescribedType responseState, boolean responseSettled)
+                               boolean sendResponseDisposition, ListDescribedType responseState, boolean responseSettled)
     {
         Matcher<Boolean> settledMatcher = null;
         if(settled)
@@ -1306,23 +1327,26 @@ public class TestAmqpPeer implements AutoCloseable
         transferMatcher.withSettled(settledMatcher);
         transferMatcher.withState(stateMatcher);
 
-        final DispositionFrame dispositionResponse = new DispositionFrame()
-                                                   .setRole(Role.RECEIVER)
-                                                   .setSettled(responseSettled)
-                                                   .setState(responseState);
+        if(sendResponseDisposition) {
+            final DispositionFrame dispositionResponse = new DispositionFrame()
+                                                       .setRole(Role.RECEIVER)
+                                                       .setSettled(responseSettled)
+                                                       .setState(responseState);
 
-        // The response frame channel will be dynamically set based on the incoming frame. Using the -1 is an illegal placeholder.
-        final FrameSender dispositionFrameSender = new FrameSender(this, FrameType.AMQP, -1, dispositionResponse, null);
-        dispositionFrameSender.setValueProvider(new ValueProvider()
-        {
-            @Override
-            public void setValues()
+            // The response frame channel will be dynamically set based on the incoming frame. Using the -1 is an illegal placeholder.
+            final FrameSender dispositionFrameSender = new FrameSender(this, FrameType.AMQP, -1, dispositionResponse, null);
+            dispositionFrameSender.setValueProvider(new ValueProvider()
             {
-                dispositionFrameSender.setChannel(transferMatcher.getActualChannel());
-                dispositionResponse.setFirst(transferMatcher.getReceivedDeliveryId());
-            }
-        });
-        transferMatcher.onCompletion(dispositionFrameSender);
+                @Override
+                public void setValues()
+                {
+                    dispositionFrameSender.setChannel(transferMatcher.getActualChannel());
+                    dispositionResponse.setFirst(transferMatcher.getReceivedDeliveryId());
+                }
+            });
+
+            transferMatcher.onCompletion(dispositionFrameSender);
+        }
 
         addHandler(transferMatcher);
     }
@@ -1562,4 +1586,15 @@ public class TestAmqpPeer implements AutoCloseable
             _firstAssertionError = ae;
         }
     }
+
+    public void expectSaslHeaderThenDrop() {
+        AmqpPeerRunnable exitAfterHeader = new AmqpPeerRunnable() {
+            @Override
+            public void run() {
+                _driverRunnable.exitReadLoopEarly();
+            }
+        };
+
+        addHandler(new HeaderHandlerImpl(AmqpHeader.SASL_HEADER, AmqpHeader.SASL_HEADER, exitAfterHeader));
+    }
 }
